package App::summ;

our $DATE = '2018-07-07'; # DATE
our $VERSION = '0.001'; # VERSION

1;
# ABSTRACT: Print summary statistics of a series of numbers

__END__

=pod

=encoding UTF-8

=head1 NAME

App::summ - Print summary statistics of a series of numbers

=head1 VERSION

This document describes version 0.001 of App::summ (from Perl distribution App-summ), released on 2018-07-07.

=head1 SYNOPSIS

See the command-line script L<summ>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-summ>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-summ>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-summ>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<List::Util>, L<Statistics::Basic>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
